/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.retrascope.basis;

import java.util.HashMap;
import java.util.Map;

/**
 * This class represents an entity identifier.
 * 
 * @author <a href="mailto:kamkin@ispras.ru">Alexander Kamkin</a>
 */
public final class EntityType implements Comparable<EntityType> {

  // The entity type identifier.
  private final String typeId;

  // The cache of the entity types.
  private static final Map<String, EntityType> TYPE_CACHE = new HashMap<>();

  /**
   * Constructs an entity type.
   *
   * @param typeId the entity type identifier.
   */
  private EntityType(final String typeId) {
    this.typeId = typeId;
  }

  /**
   * Returns the entity type with the given identifier.
   * 
   * @param typeId the entity type identifier
   * @return the entity type.
   */
  public static EntityType get(final String typeId) {
    EntityType result = TYPE_CACHE.get(typeId);

    if (result == null) {
      result = new EntityType(typeId);
      TYPE_CACHE.put(typeId, result);
    }

    return result;
  }

  /**
   * Returns the entity type identifier.
   * 
   * @return the entity type identifier.
   */
  public String getId() {
    return typeId;
  }

  @Override
  public String toString() {
    return typeId;
  }

  @Override
  public boolean equals(final Object obj) {
    if (!(obj instanceof EntityType)) {
      return false;
    }

    final EntityType rhs = (EntityType) obj;
    return typeId.equals(rhs.typeId);
  }

  @Override
  public int hashCode() {
    return typeId.hashCode();
  }

  @Override
  public int compareTo(final EntityType rhs) {
    return typeId.compareTo(rhs.typeId);
  }
}
