/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.retrascope.engine.basis;

import ru.ispras.retrascope.basis.Engine;
import ru.ispras.retrascope.basis.Entity;
import ru.ispras.retrascope.basis.EntityType;
import ru.ispras.retrascope.result.test.Test;

import java.util.Map;

/**
 * The class representing an abstract test generator.
 *
 * @author <a href="mailto:i.melnichenko@deltasolutions.ru">Igor Melnichenko</a>
 */
public abstract class TestGenerator extends Engine {

  /**
   * Constructs an empty test generator with the specified ID and input entity type.
   * 
   * @param id the ID of this test generator
   * @param inputType the type of the input entity
   */
  public TestGenerator(String id, EntityType inputType) {
    super(id, inputType, EntityType.get(Test.ENTITY_TYPE_ID));
  }

  /**
   * Generates a test, that is, a list of input sequences.
   *
   * @param inputs a map containing input entities and their types
   *
   * @return the generated test
   */
  @Override
  public abstract Test start(Map<EntityType, Entity> inputs);
}
