/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ru.ispras.retrascope.engine.cfg;

import ru.ispras.retrascope.model.cfg.CfgVisitor;
import ru.ispras.retrascope.model.cfg.CfgWalkerMode;

/**
 * Base class for visitor-based back-ends running in "depth-first-search" mode.
 *
 * <p>Basic class for control flow graph {@link ru.ispras.retrascope.model.cfg.CfgModel}
 * visitors {@link ru.ispras.retrascope.model.cfg.CfgVisitor} that are called by
 * walker {@link ru.ispras.retrascope.model.cfg.CfgWalker} running at
 * Depth-First-Search walker mode {@link ru.ispras.retrascope.model.cfg.CfgWalkerMode}.</p>
 *
 * @author <a href="mailto:smolov@ispras.ru">Sergey Smolov</a>
 */
public final class CfgDfsVisitorBackend extends CfgVisitorBackend {

  /**
   * Constructs object with the specified visitor.
   * <p>Constructs object with the specified visitor and {@code CfgWalkerMode.DFS}
   * walking mode.</p>
   * @param visitor visitor
   */
  public CfgDfsVisitorBackend(final CfgVisitor visitor) {
    super(visitor, CfgWalkerMode.DFS);
  }
}
