/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ru.ispras.retrascope.engine.cgaa.transformer.efsm;

import ru.ispras.fortress.expression.Node;
import ru.ispras.fortress.util.InvariantChecks;
import ru.ispras.retrascope.model.efsm.GuardedAction;

import java.util.Set;

/**
 * The auxiliary class for GADD-diagram to EFSM-model transformer.
 *
 * @author <a href="mailto:smolov@ispras.ru">Sergey Smolov</a>
 */
final class EfsmDataContainer {

  /* The conjunction of state sub-expressions. */
  private final Set<Node> state;

  /* The outgoing-from-state guarded actions. */
  private final GuardedAction guardedAction;

  /**
   * Constructs object from the specified state expression
   * and the specified guarded action.
   *
   * @param state state expression
   * @param guardedAction guarded action
   *
   * @throws IllegalArgumentException when any of the arguments is {@code null}.
   */
  public EfsmDataContainer(
      final Set<Node> state,
      final GuardedAction guardedAction) {
    InvariantChecks.checkNotNull(state);
    InvariantChecks.checkNotNull(guardedAction);

    this.state = state;
    this.guardedAction = guardedAction;
  }

  /**
   * Returns state expression.
   *
   * @return state expression
   */
  public Set<Node> getState() {
    return this.state;
  }

  /**
   * Returns guarded action.
   *
   * @return guarded action
   */
  public GuardedAction getGuardedAction() {
    return this.guardedAction;
  }
}
