/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package ru.ispras.retrascope.engine.efsm.generator.test.heuristic.direction;

import ru.ispras.retrascope.model.efsm.EfsmTransition;

/**
 * The abstract class representing an heuristic for choosing EFSM transitions to traverse.
 *
 * @author <a href="mailto:i.melnichenko@deltasolutions.ru">Igor Melnichenko</a>
 */
public abstract class EfsmTransitionChooser {
  /**
   * Chooses and returns a transition for traversing.
   * 
   * @return the transition proposed for traversing. {@code null} is
   * returned if all choosable transitions were chosen or there are no choosable transitions at all
   */
  public abstract EfsmTransition chooseNext();

  /**
   * Checks if there is at least one non-chosen transition now.
   *
   * @return {@code true} if there is at least one non-chosen transition. Otherwise returns
   * {@code false}
   */
  public abstract boolean hasNext();
}
