/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package ru.ispras.retrascope.engine.efsm.simulator;

import ru.ispras.retrascope.engine.efsm.EfsmTransitionCoverage;
import ru.ispras.retrascope.model.basis.memory.HashMapMemory;
import ru.ispras.retrascope.model.efsm.EfsmState;
import ru.ispras.retrascope.model.efsm.EfsmTransition;

/**
 * The snapshot of EFSM simulation.
 *
 * @author <a href="mailto:i.melnichenko@deltasolutions.ru">Igor Melnichenko</a>
 *
 * @see EfsmSimulator
 */
public final class EfsmSimulationSnapshot {
  final EfsmState currentState;
  final EfsmTransition lastTraversedTransition;

  final HashMapMemory inputsMemory;
  final HashMapMemory outputsMemory;
  final HashMapMemory innerVariablesMemory;

  final EfsmTransitionCoverage coverage;

  /**
   * Constructs a snapshot of current state of the specified simulator.
   *
   * @param simulator the simulator
   */
  EfsmSimulationSnapshot(EfsmSimulator simulator) {
    this.currentState = new EfsmState(simulator.currentState.getExpression());
    this.lastTraversedTransition = simulator.lastTraversedTransition;

    this.inputsMemory = new HashMapMemory(simulator.inputsMemory);
    this.innerVariablesMemory = new HashMapMemory(simulator.innerVariablesMemory);
    this.outputsMemory = new HashMapMemory(simulator.outputsMemory);

    this.coverage = new EfsmTransitionCoverage(simulator.coverage);
  }
}
