/*
 * Copyright 2013 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.retrascope.model.basis;

/**
 * Event types.
 * 
 * @author <a href="mailto:smolov@ispras.ru">Sergey Smolov</a>
 * 
 */
public enum EventType {
  NEGATIVE_EDGE, // for falling edge events
  POSITIVE_EDGE, // for rising edge events
  ANY_EDGE       // for arbitrary (any-of-other) events
  ;

  /* String compact representations for event type. */
  private static final String POS_EDGE = "posedge";
  private static final String NEG_EDGE = "negedge";

  /**
   * Returns compact string representation.
   *
   * <p>Returns empty string when object is neither of rising edge
   * nor of falling edge kind</p>
   *
   * @return string representation
   */
  public String toCompactString() {
    String result;
    switch (this) {
      case POSITIVE_EDGE:
        result = POS_EDGE;
        break;
      case NEGATIVE_EDGE:
        result = NEG_EDGE;
        break;
      default:
        result = "";
        break;
    }
    return result;
  }
}
