/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.retrascope.model.basis;

import ru.ispras.fortress.util.InvariantChecks;

/**
 * Variable data descriptor.
 *
 * <p>Should be stored in the user data field of node variable object.</p>
 * 
 * @author <a href="mailto:smolov@ispras.ru">Sergey Smolov</a>
 */
public class VariableData extends MetaInfo {

  /* The variable type. */
  private final VariableType variableType;

  /**
   * Constructs object with the specified variable type.
   *
   * @param variableType variable type
   *
   * @throws IllegalArgumentException when argument is {@code null}.
   */
  public VariableData(final VariableType variableType) {
    super();
    InvariantChecks.checkNotNull(variableType);

    this.variableType = variableType;
  }

  /**
   * Returns variable type.
   *
   * @return variable type
   */
  public VariableType getVariableType() {
    return this.variableType;
  }

  @Override
  public boolean equals(final Object obj) {
    if (this == obj) {
      return true;
    }
    if (obj == null || getClass() != obj.getClass()) {
      return false;
    }

    final VariableData that = (VariableData) obj;

    return this.variableType == that.variableType;
  }

  @Override
  public int hashCode() {
    return this.variableType.hashCode();
  }
}
