/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.retrascope.model.cfg;

import ru.ispras.fortress.expression.NodeVariable;

import java.util.Collection;
import java.util.LinkedHashSet;
import java.util.Set;

/**
 * Sink (final) node of control flow graph.
 *
 * <p>Sink node does not have child nodes and has only one parent node.</p>
 * 
 * @author <a href="mailto:smolov@ispras.ru">Sergey Smolov</a>
 */
public class Sink extends CfgNode {

  /**
   * Default constructor.
   */
  public Sink() {
    super();
  }

  @Override
  public CfgModelNode deepCopy() {
    return new Sink();
  }

  @Override
  public boolean hasParents() {
    return this.parentNode != null;
  }

  @Override
  public boolean hasOnlyParent() {
    return this.parentNode != null;
  }

  @Override
  public CfgModelNode getOnlyChild() {
    return null;
  }

  /**
   * Throws an exception, because object does not have child nodes.
   *
   * @param node child node
   *
   * @throws java.lang.UnsupportedOperationException every time it is called.
   */
  @Override
  public void addChild(final CfgModelNode node) {
    throw new UnsupportedOperationException("No child nodes for: " + getType() + ".");
  }

  /**
   * Throws an exception, because object does not have child nodes.
   *
   * @param node child node
   *
   * @throws java.lang.UnsupportedOperationException every time it is called.
   */
  @Override
  public void removeChild(final CfgModelNode node) {
    throw new UnsupportedOperationException("No child nodes for: " + getType() + ".");
  }

  @Override
  public Collection<CfgModelNode> getChildren() {
    return new LinkedHashSet<>();
  }

  @Override
  public CfgNodeType getType() {
    return CfgNodeType.SINK;
  }

  @Override
  public boolean hasChildren() {
    return false;
  }

  @Override
  public boolean hasOnlyChild() {
    return false;
  }

  @Override
  public CfgModelNode getOnlyParent() {
    return this.parentNode;
  }

  @Override
  public Set<NodeVariable> getUses() {
    return new LinkedHashSet<>();
  }

  @Override
  public Set<NodeVariable> getDefines() {
    return new LinkedHashSet<>();
  }
}
