/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ru.ispras.retrascope.model.cgaa;

import ru.ispras.fortress.util.InvariantChecks;
import ru.ispras.retrascope.basis.Entity;
import ru.ispras.retrascope.basis.EntityType;
import ru.ispras.retrascope.model.cfg.CfgModel;

/**
 * Clocked Guarded Atomic Actions (i.e. CGAA) model.
 *
 * <p>The model is control flow graph {@link ru.ispras.retrascope.model.cfg.CfgModel} model
 * that is stored in the form of the clocked guarded actions decision diagram.</p>
 *
 * @author <a href="mailto:smolov@ispras.ru">Sergey Smolov</a>
 */
public class CgaaModel extends Entity {

  /**
   * The entity type.
   */
  public static final EntityType TYPE = EntityType.get("cgaa");

  /* The internal model. */
  private final CfgModel model;

  /**
   * Constructs an object with the specified control flow graph internal model.
   *
   * @param model the internal model
   *
   * @throws IllegalArgumentException when argument is {@code null}.
   */
  public CgaaModel(final CfgModel model) {
    super(CgaaModel.TYPE);
    InvariantChecks.checkNotNull(model);

    this.model = model;
  }

  /**
   * Adds the specified entity.
   *
   * @param entity the entity to be added
   *
   * @throws IllegalArgumentException when argument is either {@code null}
   *         or not of {@code CgaaModel} type.
   */
  @Override
  public void add(final Entity entity) {
    InvariantChecks.checkNotNull(entity);

    if (entity instanceof CgaaModel) {

      this.model.add(((CgaaModel) entity).getModel());

    } else {
      throw new IllegalArgumentException("Incorrect type: " + entity.getEntityType().getId() + ".");
    }
  }

  /**
   * Returns the internal {@link CfgModel} model.
   *
   * @return model
   */
  public CfgModel getModel() {
    return this.model;
  }
}
