/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ru.ispras.retrascope.model.efsm;

/**
 * The interface for EFSM model visitors. Typically, EFSM model visitors are used along with EFSM
 * model walkers.
 *
 * @author <a href="mailto:i.melnichenko@deltasolutions.ru">Igor Melnichenko</a>
 *
 * @see EfsmModel
 * @see EfsmModelWalker
 */
public interface EfsmModelVisitor extends EfsmVisitor {
  /**
   * Indicates that a walker has started walking across the specified EFSM model.
   *
   * @param efsmModel the visited EFSM model
   */
  public void onEfsmModelBegin(EfsmModel efsmModel);

  /**
   * Indicates that a walker has finished walking across the specified EFSM model.
   *
   * @param efsmModel the visited EFSM model
   */
  public void onEfsmModelEnd(EfsmModel efsmModel);
}
