/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ru.ispras.retrascope.model.efsm;

import ru.ispras.fortress.util.InvariantChecks;

/**
 * The walker for the {@link EfsmModel} class.
 *
 * @author <a href="mailto:i.melnichenko@deltasolutions.ru">Igor Melnichenko</a>
 */
public class EfsmModelWalker extends EfsmWalker {
  private final EfsmModelVisitor visitor;

  /**
   * Constructs a walker for the specified visitor.
   *
   * @param visitor the visitor
   */
  public EfsmModelWalker(EfsmModelVisitor visitor) {
    super(visitor);
    this.visitor = visitor;
  }

  /**
   * Performs walking across the specified test.
   *
   * @param efsmModel the EFSM model to be walked across
   *
   * @throws IllegalArgumentException if {@code efsmModel} is {@code null}
   */
  public void start(EfsmModel efsmModel) {
    InvariantChecks.checkNotNull(efsmModel);

    this.visitor.onEfsmModelBegin(efsmModel);

    for (Efsm efsm: efsmModel.getEfsmList()) {
      super.start(efsm);
    }

    this.visitor.onEfsmModelEnd(efsmModel);
  }
}
