/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ru.ispras.retrascope.parser.basis;

import ru.ispras.retrascope.basis.Engine;
import ru.ispras.retrascope.basis.Entity;
import ru.ispras.retrascope.basis.EntityType;
import ru.ispras.retrascope.engine.cfg.CfgDfsVisitorBackend;
import ru.ispras.retrascope.engine.cfg.CfgDfsWrVisitorBackend;
import ru.ispras.retrascope.parser.basis.backend.CfgBasicBlockSequenceBackend;
import ru.ispras.retrascope.parser.basis.backend.CfgConcurrentBasicBlockBackend;
import ru.ispras.retrascope.parser.basis.backend.CfgLoopBackend;
import ru.ispras.retrascope.parser.basis.backend.CfgMergeSequenceBackend;
import ru.ispras.retrascope.parser.basis.backend.CfgOneAssignmentProcessBackend;
import ru.ispras.retrascope.parser.basis.backend.CfgSwitchSequenceBackend;
import ru.ispras.retrascope.parser.basis.backend.CfgWaitBackend;

import java.util.Map;

/**
 * HDL parser basic class.
 *
 * <p>Returns {@link ru.ispras.retrascope.model.cfg.CfgModel}
 * control flow graph model representation.</p>
 *
 * @author <a href="mailto:smolov@ispras.ru">Sergey Smolov</a>
 */
public abstract class HdlParser extends Engine {

  /**
   * Constructs parser with the specified identifier.
   *
   * @param parserId parser identifier
   */
  protected HdlParser(final String parserId) {
    super(parserId);

    /* Parser back-ends registration. */
    addBackend(new CfgDfsVisitorBackend(new CfgLoopBackend()));
    addBackend(new CfgDfsVisitorBackend(new CfgWaitBackend()));
    addBackend(new CfgDfsWrVisitorBackend(new CfgBasicBlockSequenceBackend()));
    addBackend(new CfgDfsWrVisitorBackend(new CfgConcurrentBasicBlockBackend()));
    addBackend(new CfgDfsWrVisitorBackend(new CfgOneAssignmentProcessBackend()));
    addBackend(new CfgDfsWrVisitorBackend(new CfgSwitchSequenceBackend()));
    addBackend(new CfgDfsWrVisitorBackend(new CfgMergeSequenceBackend()));
  }

  /**
   * Parses input entities.
   *
   * @param inputs input entities collection
   *
   * @return output entity
   */
  public abstract Entity parse(final Map<EntityType, Entity> inputs);

  @Override
  public Entity start(final Map<EntityType, Entity> inputs) {
    return parse(inputs);
  }
}
