/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package ru.ispras.retrascope.parser.test;

import java.util.Collection;

import ru.ispras.retrascope.basis.FileNames;

/**
 * This class represents a collection of XML file names.
 *
 * @author <a href="mailto:i.melnichenko@deltasolutions.ru">Igor Melnichenko</a>
 */
public class TestFileNames extends FileNames {
  /**
   * The entity type ID of all {@code TestFileNames} instances.
   */
  public static final String ENTITY_TYPE_ID = "test-xml".intern();

  /**
   * Constructs a test file names entity initialised with the specified file name.
   *
   * @param fileName the file name
   */
  public TestFileNames(String fileName) {
    super(TestFileNames.ENTITY_TYPE_ID);
    this.add(fileName);
  }

  /**
   * Constructs a test file names entity initialised with the specified file names.
   *
   * @param fileNames the file names
   */
  public TestFileNames(Collection<String> fileNames) {
    super(TestFileNames.ENTITY_TYPE_ID);

    for (String fileName: fileNames) {
      this.add(fileName);
    }
  }
}
