/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package ru.ispras.retrascope.parser.test;

import java.nio.file.Paths;
import java.util.Map;
import java.util.logging.Logger;

import javax.xml.bind.JAXB;

import ru.ispras.retrascope.basis.Engine;
import ru.ispras.retrascope.basis.Entity;
import ru.ispras.retrascope.basis.EntityType;
import ru.ispras.retrascope.result.test.Test;
import ru.ispras.retrascope.util.Log;
import ru.ispras.retrascope.util.LogLevel;

/**
 * The class for unmarshalling tests from XML files.
 *
 * @author <a href="mailto:i.melnichenko@deltasolutions.ru">Igor Melnichenko</a>
 *
 * @see ru.ispras.retrascope.result.test.Test
 */
public class XmlTestParser extends Engine {
  private static final String ENGINE_ID = "xml-test-parser";

  private final Logger logger;
  private final String logEntryHeader;

  /**
   * Creates a new XML test parser.
   */
  public XmlTestParser() {
    super(XmlTestParser.ENGINE_ID, EntityType.get(TestFileNames.ENTITY_TYPE_ID),
        EntityType.get(Test.ENTITY_TYPE_ID));

    this.logEntryHeader = "XML test parser: ";
    this.logger = Log.getLogger(this.getClass());
  }

  @Override
  public Test start(Map<EntityType, Entity> inputs) {
    TestFileNames testFileNames =
        ((TestFileNames) inputs.get(EntityType.get(TestFileNames.ENTITY_TYPE_ID)));

    if (testFileNames == null) {
      throw new IllegalArgumentException("No entities " + TestFileNames.ENTITY_TYPE_ID +
          " found among inputs");
    }

    String fileName = testFileNames.getArray()[0];

    this.logger.log(LogLevel.INFO, this.logEntryHeader +
        "starting to unmarshal a test from the file " + fileName);

    Test test = JAXB.unmarshal(Paths.get(fileName).toFile(), Test.class);

    this.logger.log(LogLevel.INFO, this.logEntryHeader +
        "the test has been successfully unmarshalled " + test);

    return test;
  }
}
