/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ru.ispras.retrascope.result.cfginterface;

import ru.ispras.fortress.expression.NodeVariable;
import ru.ispras.fortress.util.InvariantChecks;

import java.util.Collection;

/**
 * Signal part of control flow graph model interface.
 *
 * <p>Signal part of {@link ru.ispras.retrascope.result.cfginterface.CfgInterface} interface.
 * This part contains interface's input and output signals.</p>
 *
 * @author <a href="mailto:smolov@ispras.ru">Sergey Smolov</a>
 */
public class CfgSignalInterface {

  /* Input signals. */
  private final Collection<NodeVariable> inputs;

  /* Output signals. */
  private final Collection<NodeVariable> outputs;

  /**
   * Constructs object with the specified input and output signals.
   *
   * @param inputs input signals
   * @param outputs output signals
   *
   * @throws IllegalArgumentException when any of arguments is {@code null}.
   */
  public CfgSignalInterface(
      final Collection<NodeVariable> inputs,
      final Collection<NodeVariable> outputs) {
    InvariantChecks.checkNotNull(inputs);
    InvariantChecks.checkNotNull(outputs);

    this.inputs = inputs;
    this.outputs = outputs;
  }

  /**
   * Returns input signals.
   *
   * @return input signals
   */
  public Collection<NodeVariable> getInputs() {
    return this.inputs;
  }

  /**
   * Returns output signals.
   *
   * @return output signals
   */
  public Collection<NodeVariable> getOutputs() {
    return this.outputs;
  }
}
