/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.retrascope.result.test;

import ru.ispras.fortress.expression.Node;
import ru.ispras.retrascope.model.basis.Event;
import ru.ispras.retrascope.model.basis.EventList;

/**
 * The interface for test visitors. Typically, test visitors are used along with test walkers.
 *
 * @author <a href="mailto:i.melnichenko@deltasolutions.ru">Igor Melnichenko</a>
 *
 * @see Test
 * @see TestWalker
 */
public interface TestVisitor {
  /**
   * Indicates that a walker has started walking across the specified test.
   *
   * @param test the visited test
   */
  public void onTestBegin(Test test);

  /**
   * Indicates that a walker has finished walking across the specified test.
   *
   * @param test the visited test
   */
  public void onTestEnd(Test test);

  /**
   * Indicates that a walker has started walking across the specified sequence.
   *
   * @param sequence the visited sequence
   */
  public void onSequenceBegin(Sequence sequence);

  /**
   * Indicates that a walker has finished walking across the specified sequence.
   *
   * @param sequence the visited sequence
   */
  public void onSequenceEnd(Sequence sequence);

  /**
   * Indicates that a walker has started walking across the specified vector.
   *
   * @param vector the visited vector
   */
  public void onVectorBegin(Vector vector);

  /**
   * Indicates that a walker has finished walking across the specified vector.
   *
   * @param vector the visited vector
   */
  public void onVectorEnd(Vector vector);

  /**
   * Indicates that a walker has started walking across the specified transaction.
   *
   * @param transaction the visited transaction
   */
  public void onTransactionBegin(Transaction transaction);

  /**
   * Indicates that a walker has finished walking across the specified transaction.
   *
   * @param transaction the visited transaction
   */
  public void onTransactionEnd(Transaction transaction);

  /**
   * Indicates that a walker has started walking across the specified event list.
   *
   * @param eventList the visited eventList
   */
  public void onEventListBegin(EventList eventList);

  /**
   * Indicates that walker has finished walking across the specified event list.
   *
   * @param eventList the visited eventList
   */
  public void onEventListEnd(EventList eventList);

  /**
   * Indicates that a walker has encountered the specified event.
   *
   * @param event the encountered event
   */
  public void onEvent(Event event);

  /**
   * Indicates that a walker has encountered the specified variable.
   *
   * @param name a name of the encountered signal
   * @param value a value of the encountered signal
   */
  public void onVariable(String name, Node value);
}
