/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.retrascope.result.test.jaxb;

import java.util.Map;

import javax.xml.bind.annotation.adapters.XmlAdapter;

import org.apache.commons.collections15.map.HashedMap;

import ru.ispras.fortress.expression.Node;

/**
 * The adapter class for JAXB marshalling/unmarshalling of variables.  
 *
 * @author <a href="mailto:i.melnichenko@deltasolutions.ru">Igor Melnichenko</a>
 */
public class JaxbVariableMapXmlAdapter extends XmlAdapter<JaxbVariableList, Map<String, Node>> {
  @Override
  public JaxbVariableList marshal(Map<String, Node> v) throws Exception {
    JaxbVariableList jaxbVariableList = new JaxbVariableList();

    for (String name: v.keySet()) {
      JaxbVariable jaxbVariable = new JaxbVariable();
      jaxbVariable.name = name;
      jaxbVariable.data = v.get(name);
      jaxbVariableList.jaxbVariables.add(jaxbVariable);
    }

    return jaxbVariableList;
  }

  @Override
  public Map<String, Node> unmarshal(JaxbVariableList v) throws Exception {
    Map<String, Node> variables = new HashedMap<>(v.jaxbVariables.size());

    for (JaxbVariable jaxbVariable: v.jaxbVariables) {
      variables.put(jaxbVariable.name, jaxbVariable.data);
    }

    return variables;
  }
}
