/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package ru.ispras.retrascope.result.testbench;

import java.nio.file.Path;
import java.util.Set;

import ru.ispras.retrascope.basis.Entity;
import ru.ispras.retrascope.basis.FileNames;

/**
 * The representation of a VHDL testbench.
 *
 * @author <a href="mailto:i.melnichenko@deltasolutions.ru">Igor Melnichenko</a>
 */
public class VhdlTestbench extends Testbench {
  /**
   * The entity type ID of all {@code VhdlTestbench} instances.
   *
   * @see ru.ispras.retrascope.basis.EntityType#get(String)
   * @see Entity#Entity(ru.ispras.retrascope.basis.EntityType)
   */
  public static final String ENTITY_TYPE_ID = "vhdl-testbench".intern();

  /**
   * Constructs a new VHDL testbench with the specified testbench file and additional files (for
   * example, test pattern and library files).
   *
   * @param testbenchFile a path to the testbench file. It is accessible via the
   * {@link Testbench#getTestbenchFile()}, {@link FileNames#getArray()} and
   * {@link FileNames#getList()} methods
   * @param additionalFiles a set containing additional files of the testbench
   */
  public VhdlTestbench(Path testbenchFile, Set<Path> additionalFiles) {
    super(VhdlTestbench.ENTITY_TYPE_ID, testbenchFile, additionalFiles);
  }
}
